# Spdx

[Licensecheck Index](../../README.md#licensecheck-index) / [Licensecheck](../index.md#licensecheck) / [License Matrix](./index.md#license-matrix) / Spdx

> Auto-generated documentation for [licensecheck.license_matrix.spdx](../../../../licensecheck/license_matrix/spdx.py) module.
- [Spdx](#spdx)
